/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataMongodbatlasApiKeyProjectAssignmentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique 24-hexadecimal digit string that identifies this organization API key that you want to assign to one project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.38.0/docs/data-sources/api_key_project_assignment#api_key_id DataMongodbatlasApiKeyProjectAssignment#api_key_id}
    */
    readonly apiKeyId: string;
    /**
    * Unique 24-hexadecimal digit string that identifies your project. Use the [/groups](#tag/Projects/operation/listProjects) endpoint to retrieve all projects to which the authenticated user has access.
    *
    * **NOTE**: Groups and projects are synonymous terms. Your group id is the same as your project id. For existing groups, your group/project id remains the same. The resource and corresponding endpoints use the term groups.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.38.0/docs/data-sources/api_key_project_assignment#project_id DataMongodbatlasApiKeyProjectAssignment#project_id}
    */
    readonly projectId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.38.0/docs/data-sources/api_key_project_assignment mongodbatlas_api_key_project_assignment}
*/
export declare class DataMongodbatlasApiKeyProjectAssignment extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "mongodbatlas_api_key_project_assignment";
    /**
    * Generates CDKTF code for importing a DataMongodbatlasApiKeyProjectAssignment resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataMongodbatlasApiKeyProjectAssignment to import
    * @param importFromId The id of the existing DataMongodbatlasApiKeyProjectAssignment that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.38.0/docs/data-sources/api_key_project_assignment#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataMongodbatlasApiKeyProjectAssignment to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.38.0/docs/data-sources/api_key_project_assignment mongodbatlas_api_key_project_assignment} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataMongodbatlasApiKeyProjectAssignmentConfig
    */
    constructor(scope: Construct, id: string, config: DataMongodbatlasApiKeyProjectAssignmentConfig);
    private _apiKeyId?;
    get apiKeyId(): string;
    set apiKeyId(value: string);
    get apiKeyIdInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    get roles(): string[];
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
