/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataMongodbatlasApiKeyProjectAssignmentsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique 24-hexadecimal digit string that identifies your project. Use the [/groups](#tag/Projects/operation/listProjects) endpoint to retrieve all projects to which the authenticated user has access.
    *
    * **NOTE**: Groups and projects are synonymous terms. Your group id is the same as your project id. For existing groups, your group/project id remains the same. The resource and corresponding endpoints use the term groups.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.38.0/docs/data-sources/api_key_project_assignments#project_id DataMongodbatlasApiKeyProjectAssignments#project_id}
    */
    readonly projectId: string;
}
export interface DataMongodbatlasApiKeyProjectAssignmentsResults {
}
export declare function dataMongodbatlasApiKeyProjectAssignmentsResultsToTerraform(struct?: DataMongodbatlasApiKeyProjectAssignmentsResults): any;
export declare function dataMongodbatlasApiKeyProjectAssignmentsResultsToHclTerraform(struct?: DataMongodbatlasApiKeyProjectAssignmentsResults): any;
export declare class DataMongodbatlasApiKeyProjectAssignmentsResultsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataMongodbatlasApiKeyProjectAssignmentsResults | undefined;
    set internalValue(value: DataMongodbatlasApiKeyProjectAssignmentsResults | undefined);
    get apiKeyId(): string;
    get projectId(): string;
    get roles(): string[];
}
export declare class DataMongodbatlasApiKeyProjectAssignmentsResultsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataMongodbatlasApiKeyProjectAssignmentsResultsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.38.0/docs/data-sources/api_key_project_assignments mongodbatlas_api_key_project_assignments}
*/
export declare class DataMongodbatlasApiKeyProjectAssignments extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "mongodbatlas_api_key_project_assignments";
    /**
    * Generates CDKTF code for importing a DataMongodbatlasApiKeyProjectAssignments resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataMongodbatlasApiKeyProjectAssignments to import
    * @param importFromId The id of the existing DataMongodbatlasApiKeyProjectAssignments that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.38.0/docs/data-sources/api_key_project_assignments#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataMongodbatlasApiKeyProjectAssignments to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.38.0/docs/data-sources/api_key_project_assignments mongodbatlas_api_key_project_assignments} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataMongodbatlasApiKeyProjectAssignmentsConfig
    */
    constructor(scope: Construct, id: string, config: DataMongodbatlasApiKeyProjectAssignmentsConfig);
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _results;
    get results(): DataMongodbatlasApiKeyProjectAssignmentsResultsList;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
